#
# Copyright (c) 2011 LAAS/CNRS
# All rights reserved.
#
# Permission to use, copy, modify, and distribute this software for any purpose
# with or without   fee is hereby granted, provided   that the above  copyright
# notice and this permission notice appear in all copies.
#
# THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
# REGARD TO THIS  SOFTWARE INCLUDING ALL  IMPLIED WARRANTIES OF MERCHANTABILITY
# AND FITNESS. IN NO EVENT SHALL THE AUTHOR  BE LIABLE FOR ANY SPECIAL, DIRECT,
# INDIRECT, OR CONSEQUENTIAL DAMAGES OR  ANY DAMAGES WHATSOEVER RESULTING  FROM
# LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
# OTHER TORTIOUS ACTION,   ARISING OUT OF OR IN    CONNECTION WITH THE USE   OR
# PERFORMANCE OF THIS SOFTWARE.
#
#                                            Anthony Mallet on Sun Jul 24 2011
#

# --- main -----------------------------------------------------------------
#
proc main { } {
  global argc argv

  if { $argc < 1} { usage stderr 2 }

  switch -exact [lindex $argv 0] {
    log2db {
      if {$argc != 3} { usage stderr 2 }
      log2db [lindex $argv 1] [lindex $argv 2]
    }

    db2html {
      if {$argc != 3} { usage stderr 2 }
      db2html [lindex $argv 1] [lindex $argv 2]
    }

    default { usage stderr 2 }
  }

  return
}


# --- usage ----------------------------------------------------------------
#
proc usage { channel code } {
  global argv

  set p [file tail [info script]]
  puts $channel "Usage:	$p <command> \[<args>\]"
  puts $channel ""
  puts $channel "Commands:"
  puts $channel "	log2db <bulk-log-dir> <sqlite3-db>"
  puts $channel "	db2html <sqlite3-db> <destination>"

  exit $code
}


# --- errx -----------------------------------------------------------------
#
proc errx { code msg } {
  global argv

  set p [file tail [info script]]
  puts stderr "$p: $msg"
  exit $code
}

proc warnx { msg } {
  global argv

  set p [file tail [info script]]
  puts stderr "$p: $msg"
  return
}

proc infox { msg } {
  puts $msg
  return
}


# --- opendb ---------------------------------------------------------------
#
proc opendb { db } {
  package require sqlite3
  sqlite3 db $db

  db eval {
    create table if not exists
    pkg(
        id integer primary key,
        tag text,
        pkgname text,
        unique (tag, pkgname) on conflict ignore)
  }
  db eval {
    create table if not exists
    meta(
         id int,
         path text,
         pkgbase text,
         na int,
         date_start int,
         date_stop int,
         warning int,
         broken int,
         fixed int,
         unique (id) on conflict replace)
  }
  db eval {
    create table if not exists
    breaks(
             id integer,
             breaks integer,
             unique (id, breaks) on conflict ignore)
  }
  db eval {
    create table if not exists
    category(
             id int,
             category text,
             unique (id, category) on conflict ignore)
  }
  db eval {
    create table if not exists
    log(
        id int,
        file text,
        data text,
        unique (id, file) on conflict replace)
  }
  db eval {
    create table if not exists
    session(
        tag text,
        log text,
        date int,
        updates int,
        unique (tag) on conflict replace)
  }

  return db
}


# --- closedb --------------------------------------------------------------
#
proc closedb { db } {
  $db eval { analyze }
  $db close

  return
}
